@@ -28,7 +28,7 @@
 /* #undef HAVE_NDIR_H */
 #define HAVE_DIRENT_H 1
 #define HAVE_DLFCN_H 1
-/* #undef HAVE_EXECINFO_H */
+#define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
 #define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
@@ -103,6 +103,7 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 /* #undef HAVE_SYSTEMD */
+/* #undef HAVE_SYSTEMD_SD_LISTEN_FDS_WITH_NAMES */
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -239,9 +240,9 @@
 /* Symbols we may use */
 /* #undef HAVE_SYS_ERRLIST */
 /* used by stacktrace functions */
-/* #undef HAVE_BACKTRACE */
-/* #undef HAVE_BACKTRACE_SYMBOLS */
-/* #undef HAVE_BACKTRACE_SYMBOLS_FD */
+#define HAVE_BACKTRACE 1
+#define HAVE_BACKTRACE_SYMBOLS 1
+#define HAVE_BACKTRACE_SYMBOLS_FD 1
 /* #undef HAVE_PRINTSTACK */
 #define HAVE_IPV6 1
 /* #undef ss_family */
@@ -392,8 +393,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "amd64"
-#define DEFAULT_MACHINE "amd64"
+#define MACHINE_TYPE "aarch64"
+#define DEFAULT_MACHINE "aarch64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -428,7 +429,7 @@
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
 /* We don't want the min/max macros */
-#ifdef __WIN__
+#ifdef _WIN32
 #define NOMINMAX 1
 #endif
 
@@ -527,17 +528,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 12
+#define MYSQL_VERSION_MINOR 6
+#define MYSQL_VERSION_PATCH 4
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.12"
+#define PACKAGE_STRING "MySQL Server 10.6.4"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.12"
-#define VERSION "10.5.12"
+#define PACKAGE_VERSION "10.6.4"
+#define VERSION "10.6.4"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
